@@ -1,6 +1,41 @@
 use strict;
 use warnings;
 
+=head1 NAME
+
+Win32::MSI::HighLevel::Common - Helper module for Win32::MSI::HighLevel.
+
+=head1 VERSION
+
+Version 1.0001
+
+=head1 AUTHOR
+
+    Peter Jaquiery
+    CPAN ID: GRANDPA
+    grandpa@cpan.org
+
+=head1 COPYRIGHT & LICENSE
+
+This program is free software; you can redistribute
+it and/or modify it under the same terms as Perl itself.
+
+The full text of the license can be found in the
+LICENSE file included with this module.
+
+=cut
+
+BEGIN {
+    use Exporter ();
+    use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+    $VERSION     = '1.0001';
+    @ISA         = qw(Exporter);
+    @EXPORT      = qw();
+    @EXPORT_OK   = qw();
+    %EXPORT_TAGS = ();
+}
+
+
 package Win32::MSI::HighLevel::Common;
 
 use Exporter 'import';
